@@ -42,20 +42,19 @@ from sphinx.transforms.post_transforms import (
     SphinxPostTransform
 )
 
-# noinspection PyUnresolvedReferences
-import sphinx_rtd_theme  # noqa
-
 from sphinx.ext.intersphinx import (
     InventoryAdapter
 )
 
-
-#############
-# REFERENCE #
-#############
+# noinspection PyUnresolvedReferences
+import sphinx_rtd_theme  # noqa
 
 
-path.append(join(dirname(__name__), '..'))
+##################
+# REFERENCE PATH #
+##################
+
+path.insert(0, abspath('../..'))
 
 
 ###############
@@ -189,6 +188,10 @@ texinfo_documents = [(master_doc, project, project_title, author, project, 'A fr
 
 class SphinxPostTransformConstructor(SphinxPostTransform):
 
+    """
+    A class decorator used for applying constructor post-transforms.
+    """
+
     default_priority = 799
 
     def run(self, **kwargs):
@@ -218,15 +221,42 @@ class SphinxPostTransformConstructor(SphinxPostTransform):
                     nodes_to_remove.append((node_desc_signature, node_child))
 
             for node_child in node_desc_content:
-                if isinstance(node_child, nodes.paragraph) or isinstance(node_child, nodes.field_list):
+                if isinstance(node_child, (nodes.paragraph, nodes.field_list)):
                     nodes_to_remove.append((node_desc_content, node_child))
 
             for parent, child in nodes_to_remove:
                 parent.remove(child)
 
 
+class SphinxPostTransformLists(SphinxPostTransform):
+
+    """
+    A class decorator used for applying lists post-transforms.
+    """
+
+    default_priority = 799
+
+    def run(self, **kwargs):
+
+        for node in self.document.traverse(nodes.bullet_list):
+
+            target = node.parent
+
+            if target is None or not isinstance(target, nodes.paragraph):
+                continue
+
+            for child in target.children:
+                if isinstance(child, nodes.Text) and child.astext() == ' – ':
+                    target.remove(child)
+                    break
+
+
 class SphinxPostTransformProperties(SphinxPostTransform):
 
+    """
+    A class decorator used for applying properties post-transforms.
+    """
+
     default_priority = 799
 
     def run(self, **kwargs):
@@ -296,6 +326,7 @@ def setup(app):
 
     app.add_post_transform(SphinxPostTransformConstructor)
     app.add_post_transform(SphinxPostTransformProperties)
+    app.add_post_transform(SphinxPostTransformLists)
 
     app.add_config_value('intersphinx_aliases', {}, 'env')
     app.connect('builder-inited', _process_intersphinx_aliases)
